@@ -74,6 +74,12 @@ class ChangeLogDirective(EnvDirective, Directive):
         # 1. pull in global configuration from conf.py
         self.sections = self.env.changelog_sections
         self.inner_tag_sort = self.env.changelog_inner_tag_sort + [""]
+        self.hide_sections_from_tags = bool(
+            self.env.changelog_hide_sections_from_tags
+        )
+        self.hide_tags_in_entry = bool(
+            self.env.changelog_hide_tags_in_entry
+        )
 
         # 2. examine top level directives inside the .. changelog::
         # directive.  version, release date
@@ -205,7 +211,7 @@ class ChangeDirective(EnvDirective, Directive):
 
             return []
 
-        body_paragraph = nodes.paragraph("", "")
+        body_paragraph = nodes.paragraph("", "", classes=["caption"])
         self.state.nested_parse(content["text"], 0, body_paragraph)
 
         raw_text = _text_rawsource_from_node(body_paragraph)
@@ -222,12 +228,7 @@ class ChangeDirective(EnvDirective, Directive):
                 changelog_directive.env, hash_on_version
             ).setdefault(issue_hash, {})
             if not rec:
-                try:
-                    sorted(versions, key=_str_version_as_tuple)
-                except:
-                    import pdb
-
-                    pdb.set_trace()
+                sorted(versions, key=_str_version_as_tuple)
                 rec.update(
                     {
                         "hash": issue_hash,
